@@ -192,16 +192,17 @@ class Install(color_print):
             True)
 
         self.clTempl = ProgressTemplate(self.setProgress, self.clVars,
-                                        cltObj=useClt,
-                                        cltFilter=False,
-                                        printSUCCESS=self.printSUCCESS,
-                                        printWARNING=self.printWARNING,
-                                        printERROR=self.printERROR)
+            cltObj=useClt,
+            cltFilter=True if self.clVars.Get('cl_merge_set') == "on" \
+                      else False,
+            printSUCCESS=self.printSUCCESS,
+            printWARNING=self.printWARNING,
+            askConfirm=self.askConfirm,
+            dispatchConf=self.dispatchConf,
+            printERROR=self.printERROR)
 
         dirsFiles = self.clTempl.applyTemplates()
         try:
-            if self.clTempl.getWarning():
-                self.printWARNING(self.clTempl.getWarning())
             if self.clTempl.getError():
                 self.printERROR(self.clTempl.getError())
                 return False
@@ -216,7 +217,11 @@ class Install(color_print):
         self.clVars.Set("cl_chroot_grub","/", True)
         self.clVars.Set("cl_root_path",directory, True)
         self.clTempl = ProgressTemplate(self.setProgress,self.clVars,
-                                        cltObj=False)
+                                        cltObj=False,
+                                        printSUCCESS=self.printSUCCESS,
+                                        printWARNING=self.printWARNING,
+                                        askConfirm=self.askConfirm,
+                                        printERROR=self.printERROR)
         dirsFiles = self.clTempl.applyTemplates()
         if self.clTempl.getError():
             raise InstallError(self.clTempl.getError())
@@ -236,6 +241,7 @@ class Install(color_print):
                                         cltFilter=False,
                                         printSUCCESS=self.printSUCCESS,
                                         printWARNING=self.printWARNING,
+                                        askConfirm=self.askConfirm,
                                         printERROR=self.printERROR)
         dirsFiles = self.clTempl.applyTemplates()
         if self.clTempl.getError():
