@@ -18,9 +18,9 @@ import soaplib, sys, time, os
 import threading
 
 from soaplib.serializers.primitive import String, Integer, Any, Boolean
-from soaplib.serializers.clazz import Array, ClassSerializer
+from soaplib.serializers.clazz import Array
 from soaplib.service import rpc, DefinitionBase
-from calculate.core.server.api_types import ReturnedMessage
+from calculate.core.server.api_types import ReturnedMessage,CommonInfo
 from calculate.core.server.api_types import ChoiceValue, Table, Option, Field, \
                                            GroupField, ViewInfo, ViewParams
 from calculate.lib.datavars import VariableError,DataVarsError
@@ -38,7 +38,8 @@ from functools import wraps,WRAPPER_ASSIGNMENTS
 
 __ = getLazyLocalTranslate(_)
 
-class InstallInfo(ClassSerializer):
+
+class InstallInfo(CommonInfo):
     """Parameters for method install"""
     cl_image_filename = String
     cl_image_linux_shortname = String
@@ -79,15 +80,9 @@ class InstallInfo(ClassSerializer):
     cl_autopartition_root_size = String
 
     cl_live = Boolean
-    cl_templates_locate = Array(String)
-
     os_install_pxe = Boolean
     os_install_pxe_path = String
 
-    Default = Array(String)
-    CheckOnly = Boolean
-    CheckAll = Boolean
-
 installCatchExcept = catchExcept(VariableError,DataVarsError,
                                  cl_install.InstallError)
 
@@ -112,6 +107,7 @@ class Wsdl:
             dv.importInstall()
             dv.flIniFile()
             dv.Set('cl_action','system',True)
+            dv.Set('cl_dispatch_conf','usenew',True)
         dv.addGroup(_("Language and locale"),
             image="welcome",
             normal=('os_install_locale_lang','os_install_clock_timezone'))
@@ -184,6 +180,7 @@ class Wsdl:
         dv.flIniFile()
         dv.Set('cl_action','system',True)
         dv.Set('cl_install_type','flash')
+        dv.Set('cl_dispatch_conf','usenew',True)
         dv.addGroup(_("Flash install"),
             normal=('os_install_disk_single','cl_image_filename'),
             expert=('os_location_data',),
@@ -213,6 +210,7 @@ class Wsdl:
         dv.flIniFile()
         dv.Set('cl_action','system',True)
         dv.Set('os_install_pxe','on',True)
+        dv.Set('cl_dispatch_conf','usenew',True)
         dv.addGroup(None,
             normal=('cl_image_filename',),
             expert=('os_install_pxe_path',),
@@ -241,13 +239,15 @@ class Wsdl:
         dv.importInstall()
         dv.flIniFile()
         dv.Set('cl_action','merge',True)
-        dv.Set('cl_belong_pkg',[None],True)
+        dv.Set('cl_merge_pkg',[None],True)
+        dv.Set('cl_merge_set',"on",True)
         dv.Set('cl_setup','network',True)
         dv.addGroup(None,
             normal=('os_install_net_conf','os_install_net_data',
                     'os_install_net_fqdn','os_install_ntp'),
             expert=('os_install_net_dns','os_install_net_dns_search',
-                    'os_install_net_route_data',),
+                    'os_install_net_route_data',
+                    'cl_templates_locate',"cl_dispatch_conf","cl_verbose_set"),
             next_label=_("Save"))
         return dv
 
@@ -274,11 +274,13 @@ class Wsdl:
         dv.importInstall()
         dv.flIniFile()
         dv.Set('cl_action','merge',True)
-        dv.Set('cl_belong_pkg',[None],True)
+        dv.Set('cl_merge_pkg',[None],True)
+        dv.Set('cl_merge_set',"on",True)
         dv.Set('cl_setup','video',True)
         dv.addGroup(None,
             normal=('os_install_x11_video_drv', 'os_install_x11_resolution',
                     'os_install_x11_composite', 'os_install_fb_resolution'),
+            expert=('cl_templates_locate',"cl_dispatch_conf","cl_verbose_set"),
             next_label=_("Save"))
         return dv
 
@@ -304,11 +306,13 @@ class Wsdl:
         dv.importInstall()
         dv.flIniFile()
         dv.Set('cl_action','merge',True)
-        dv.Set('cl_belong_pkg',[None],True)
+        dv.Set('cl_merge_pkg',[None],True)
+        dv.Set('cl_merge_set',"on",True)
         dv.Set('cl_setup','locale',True)
         dv.addGroup(None,
             normal=('os_install_locale_lang',
                     'os_install_clock_timezone'),
+            expert=('cl_templates_locate',"cl_dispatch_conf","cl_verbose_set"),
             next_label=_("Save"))
         return dv
 
@@ -334,11 +338,13 @@ class Wsdl:
         dv.importInstall()
         dv.flIniFile()
         dv.Set('cl_action','merge',True)
-        dv.Set('cl_belong_pkg',[None],True)
+        dv.Set('cl_merge_pkg',[None],True)
+        dv.Set('cl_merge_set',"on",True)
         dv.Set('cl_setup','boot',True)
         dv.addGroup(None,
             normal=('os_install_mbr',
                     'os_install_kernel_scheduler'),
+            expert=('cl_templates_locate',"cl_dispatch_conf","cl_verbose_set"),
             next_label=_("Save"))
         return dv
 
@@ -366,7 +372,7 @@ class Wsdl:
         dv.Set('cl_live','off')
         dv.addGroup(None,
             normal=("cl_live",),
-            expert=('cl_templates_locate',),
+            expert=('cl_templates_locate',"cl_dispatch_conf","cl_verbose_set"),
             next_label=_("Reconfigure"))
         return dv
 
