@@ -255,10 +255,13 @@ class VariableOsInstallX11ServerSet(ReadonlyVariable):
     type = "bool"
 
     def get(self):
-        image = self.Get('cl_image')
-        if image:
-            with image as distr:
-                distrPath = image.getDirectory()
-                if isPkgInstalled('xorg-server',prefix=distrPath):
-                    return "yes"
+        try:
+            image = self.Get('cl_image')
+            if image:
+                with image as distr:
+                    distrPath = image.getDirectory()
+                    if isPkgInstalled('xorg-server',prefix=distrPath):
+                        return "yes"
+        except:
+            pass
         return "no"
