@@ -40,9 +40,9 @@ class DistroRepository(Linux):
     extensiton = ['iso','tar.bz2','tar.gz','tar.7z','tar.lzma']
 
     reDistName = re.compile("""
-                ^.*/(?P<name>%(name)s)
-                -(?P<ver>%(ver)s)
-                -(?P<march>%(march)s)
+                ^.*/(?P<os_linux_shortname>%(name)s)
+                -(?P<os_linux_ver>%(ver)s)
+                -(?P<os_arch_machine>%(march)s)
                 .(?P<ext>%(ext)s)$""" %
                 {'name':"[a-z0-9]+",
                  'ver':r"(\d+\.)*\d+",
@@ -60,11 +60,11 @@ class DistroRepository(Linux):
             if not match:
                 return {}
             distdic = match.groupdict()
-            distdic["build"] = ""
-            if "ver" in distdic:
-                if re.match("^\d{8}$", distdic["ver"]):
-                    distdic["build"] = distdic["ver"]
-                    distdic["ver"] = ""
+            distdic["os_linux_build"] = ""
+            if "os_linux_ver" in distdic:
+                if re.match("^\d{8}$", distdic["os_linux_ver"]):
+                    distdic["os_linux_build"] = distdic["os_linux_ver"]
+                    distdic["os_linux_ver"] = ""
             return distdic
 
     def getImage(self,scratch,rootType,imagePath,march=None,
@@ -121,18 +121,21 @@ class DistroRepository(Linux):
             if not d:
                 return False
             # check filter conditions
-            if system and systemByName(d['name']) != system:
+            if system and systemByName(d['os_linux_shortname']) != system:
                 return False
-            if not "name" in d or not "ver" in d:
+            if not "os_linux_shortname" in d or not "os_linux_ver" in d:
                 return False
-            if shortname and d['name'].lower() != shortname.lower():
+            if shortname and \
+                d['os_linux_shortname'].lower() != shortname.lower():
                 return False
-            if march and d['march'] != march:
+            if march and d['os_arch_machine'] != march:
                 return False
-            if version and not verCmp(getTupleVersion(d['ver']), version):
+            if version and \
+                not verCmp(getTupleVersion(d['os_linux_ver']), version):
                 return False
-            if build and "build" in d and (not d['build'].isdigit() or 
-                                           not buildCmp(int(d['build']),build)):
+            if build and "os_linux_build" in d and \
+                (not d['os_linux_build'].isdigit() or 
+                 not buildCmp(int(d['os_linux_build']),build)):
                 return False
             return True
 
@@ -167,11 +170,11 @@ class DistroRepository(Linux):
 
     def sortdistrfunc(self,x,y):
         """Func of comparing two distributive"""
-        ver1, ver2 = x[1].get('ver',""), y[1].get('ver',"")
+        ver1, ver2 = x[1].get('os_linux_ver',""), y[1].get('os_linux_ver',"")
         if ver1 and ver2 and ver1 != "0" and ver2 != "0" and ver1 != ver2:
             return cmpVersion(ver1,ver2)
-        build1 = getTupleVersion(x[1].get('build',""))
-        build2 = getTupleVersion(y[1].get('build',""))
+        build1 = getTupleVersion(x[1].get('os_linux_build',""))
+        build2 = getTupleVersion(y[1].get('os_linux_build',""))
         if  build1 != build2:
             return cmp(build1,build2)
         else:
@@ -288,20 +291,30 @@ class VariableClImageFilename(Variable,DistroRepository):
     def check(self,isoimage):
         """Set image file"""
         imageData = Distributive().getInfo(isoimage)
-        if not("name" in imageData and imageData.get('build','') and \
-            "march" in imageData):
+        if not("os_linux_shortname" in imageData and \
+               imageData.get('os_linux_build','') and \
+            "os_arch_machine" in imageData):
             raise VariableError(_("Wrong image file"))
 
     def humanImageName(self,distroinfo,filepath):
-        if all(x in distroinfo for x in ("name","march","build")):
-            distroinfo['name'] = distroinfo['name'].upper()
-            fullname = Linux.dictLinuxName.get(distroinfo['name'],"Calculate")
-            subname = Linux.dictLinuxSubName.get(distroinfo['name'],"")
+        if all(x in distroinfo for x in ("os_linux_shortname",
+                                         "os_arch_machine",
+                                         "os_linux_build")):
+            distroinfo['os_linux_shortname'] = \
+                distroinfo['os_linux_shortname'].upper()
+            fullname = distroinfo.get('os_linux_name',
+                Linux.dictLinuxName.get(
+                    distroinfo['os_linux_shortname'],"Calculate"))
+            subname = distroinfo.get('os_linux_subname',
+                  Linux.dictLinuxSubName.get(
+                    distroinfo['os_linux_shortname'],""))
             if subname:
                 subname=" %s"%subname
-            return "{fullname} {march} {build}".format(
+            vers = distroinfo['os_linux_build'] or \
+                distroinfo.get('os_linux_ver','')
+            return "{fullname} {os_arch_machine} {ver}".format(
                 fullname="%s%s"%(fullname,subname),filepath=filepath,
-                **distroinfo)
+                ver=vers,**distroinfo)
         else:
             return filepath
 
@@ -343,7 +356,7 @@ class VariableClImageArchMachine(Variable,DistroRepository):
 
     def choice(self):
         return [("",_("Not used"))]+\
-               [("auto",_("Automatic"))] + \
+               [("auto",_("Auto"))] + \
                [(x,x) for x in self.available_arch]
 
     def humanReadable(self):
@@ -354,7 +367,7 @@ class VariableClImageLinuxShortname(Variable,Linux,DistroRepository):
     Filter by shortname
     """
     value = ""
-    type = 'choice'
+    type = 'choiceedit'
     metavalue = "SYSTEM"
     opt = ['--os','-s']
 
