@@ -25,9 +25,10 @@ from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_install3',sys.modules[__name__])
 
 from calculate.lib.utils.ip import (getInterfaces,getIp,getMask,getMac,
-    cidrToMask,maskToCidr,getIpNet,isDhcpIp,checkIp,checkMask)
+    cidrToMask,maskToCidr,getIpNet,isDhcpIp,checkIp,checkMask,
+    getOperState)
 from calculate.lib.utils.device import lspci
-from calculate.lib.utils.files import listDirectory,readLinesFile
+from calculate.lib.utils.files import listDirectory,readLinesFile,process
 from calculate.lib.utils import ip
 from calculate.lib.utils.portage import isPkgInstalled
 from operator import itemgetter
@@ -82,6 +83,33 @@ class VariableOsInstallNetInterfaces(NetHelper,ReadonlyVariable):
     def get(self):
         return getInterfaces()
 
+class VariableOsInstallNetInterfacesOrig(NetHelper,ReadonlyVariable):
+    """
+    Net interface devices orig name from udev (enp0s2)
+    """
+    type = "list"
+
+    def get(self):
+        chrootPath = self.Get('cl_chroot_path')
+        pathOldUdevNet = path.join(chrootPath,
+            'etc/udev/rules.d/70-persistent-net.rules')
+        pathNewUdevNet = path.join(chrootPath,
+            'etc/udev/rules.d/80-net-name-slot.rules')
+        for foundPath in ifilter(path.exists,(pathOldUdevNet,
+                                              pathNewUdevNet)):
+            return self.Get('os_install_net_interfaces')
+        def getOrig(x):
+            try:
+                nameParam = filter(lambda x:x.startswith("ID_NET_NAME_PATH="),
+                            process("udevadm","test-builtin","net_id",
+                                    "/sys/class/net/%s"%x))
+                if nameParam:
+                    return nameParam[0].partition('=')[2].strip() or x
+            except Exception as e:
+                print str(e)
+                return x
+            return x
+        return map(getOrig,self.Get('os_install_net_interfaces'))
 
 class VariableOsNetInterfacesInfo(NetHelper,ReadonlyVariable):
     """
@@ -232,7 +260,10 @@ class VariableOsInstallNetStatus(NetHelper,Variable):
             elif ipaddr:
                 return ipaddr
             else:
-                return "off"
+                if getOperState(iface) == 'down':
+                    return "off"
+                else:
+                    return "dhcp"
         rootDevNfs = self.Get('os_root_dev') == '/dev/nfs'
         return statusValue(getIp(iface),"on" \
                            if rootDevNfs or isDhcpIp(iface) else "off")
@@ -305,7 +336,7 @@ class VariableOsInstallNetCidr(NetHelper,ReadonlyVariable):
         """
         Get CIDR of ip,net (Example: 24)
         """
-        return map(lambda x:maskToCidr(x),
+        return map(lambda x:maskToCidr(x) if x else '',
                self.Get('os_install_net_mask'))
 
 class VariableOsInstallNetMask(NetHelper,Variable):
